# Generated by roxygen2: do not edit by hand

export("%>%")
export(get_irpf)
export(get_metadata)
export(get_sections)
import(tibble)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(tidyselect,where)
